==> huaweicloudsdkiec-3.0.51-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/firewall_rule.py <==
# coding: utf-8

import re
import six





class FirewallRule:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'action': 'str',
        'description': 'str',
        'destination_ip_address': 'str',
        'destination_port': 'str',
        'enabled': 'bool',
        'id': 'str',
        'ip_version': 'int',
        'name': 'str',
        'operate_type': 'str',
        'protocol': 'str',
        'source_ip_address': 'str',
        'source_port': 'str'
    }

    attribute_map = {
        'action': 'action',
        'description': 'description',
        'destination_ip_address': 'destination_ip_address',
        'destination_port': 'destination_port',
        'enabled': 'enabled',
        'id': 'id',
        'ip_version': 'ip_version',
        'name': 'name',
        'operate_type': 'operate_type',
        'protocol': 'protocol',
        'source_ip_address': 'source_ip_address',
        'source_port': 'source_port'
    }

    def __init__(self, action=None, description=None, destination_ip_address=None, destination_port=None, enabled=None, id=None, ip_version=None, name=None, operate_type=None, protocol=None, source_ip_address=None, source_port=None):
        """FirewallRule - a model defined in huaweicloud sdk"""
        
        

        self._action = None
        self._description = None
        self._destination_ip_address = None
        self._destination_port = None
        self._enabled = None
        self._id = None
        self._ip_version = None
        self._name = None
        self._operate_type = None
        self._protocol = None
        self._source_ip_address = None
        self._source_port = None
        self.discriminator = None

        self.action = action
        if description is not None:
            self.description = description
        self.destination_ip_address = destination_ip_address
        self.destination_port = destination_port
        self.enabled = enabled
        self.id = id
        self.ip_version = ip_version
        self.name = name
        self.operate_type = operate_type
        self.protocol = protocol
        self.source_ip_address = source_ip_address
        self.source_port = source_port

    @property
    def action(self):
        """Gets the action of this FirewallRule.

        策略是否允许  取值范围：allow，deny，reject

        :return: The action of this FirewallRule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this FirewallRule.

        策略是否允许  取值范围：allow，deny，reject

        :param action: The action of this FirewallRule.
        :type: str
        """
        self._action = action

    @property
    def description(self):
        """Gets the description of this FirewallRule.

        网络ACL规则描述。

        :return: The description of this FirewallRule.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FirewallRule.

        网络ACL规则描述。

        :param description: The description of this FirewallRule.
        :type: str
        """
        self._description = description

    @property
    def destination_ip_address(self):
        """Gets the destination_ip_address of this FirewallRule.

        目的地IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :return: The destination_ip_address of this FirewallRule.
        :rtype: str
        """
        return self._destination_ip_address

    @destination_ip_address.setter
    def destination_ip_address(self, destination_ip_address):
        """Sets the destination_ip_address of this FirewallRule.

        目的地IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :param destination_ip_address: The destination_ip_address of this FirewallRule.
        :type: str
        """
        self._destination_ip_address = destination_ip_address

    @property
    def destination_port(self):
        """Gets the destination_port of this FirewallRule.

        目的地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :return: The destination_port of this FirewallRule.
        :rtype: str
        """
        return self._destination_port

    @destination_port.setter
    def destination_port(self, destination_port):
        """Sets the destination_port of this FirewallRule.

        目的地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :param destination_port: The destination_port of this FirewallRule.
        :type: str
        """
        self._destination_port = destination_port

    @property
    def enabled(self):
        """Gets the enabled of this FirewallRule.

        网络ACL规则使能开关。  取值范围：true，false

        :return: The enabled of this FirewallRule.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this FirewallRule.

        网络ACL规则使能开关。  取值范围：true，false

        :param enabled: The enabled of this FirewallRule.
        :type: bool
        """
        self._enabled = enabled

    @property
    def id(self):
        """Gets the id of this FirewallRule.

        网络ACL规则ID。  进行更新规则时，如果operate_type为add，则该值为空。

        :return: The id of this FirewallRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FirewallRule.

        网络ACL规则ID。  进行更新规则时，如果operate_type为add，则该值为空。

        :param id: The id of this FirewallRule.
        :type: str
        """
        self._id = id

    @property
    def ip_version(self):
        """Gets the ip_version of this FirewallRule.

        IP协议版本  取值范围：4[、6](tag:hide)

        :return: The ip_version of this FirewallRule.
        :rtype: int
        """
        return self._ip_version

    @ip_version.setter
    def ip_version(self, ip_version):
        """Sets the ip_version of this FirewallRule.

        IP协议版本  取值范围：4[、6](tag:hide)

        :param ip_version: The ip_version of this FirewallRule.
        :type: int
        """
        self._ip_version = ip_version

    @property
    def name(self):
        """Gets the name of this FirewallRule.

        网络ACL规则名称。

        :return: The name of this FirewallRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FirewallRule.

        网络ACL规则名称。

        :param name: The name of this FirewallRule.
        :type: str
        """
        self._name = name

    @property
    def operate_type(self):
        """Gets the operate_type of this FirewallRule.

        网络ACL规则操作状态，作为请求时取值为\"add\"/\"modify\"/\"delete\"，作为返回值时为\"normal\"。 当请求更新规则时，本参数值为delete时，除id之外，本请求体其他参数均可为空。

        :return: The operate_type of this FirewallRule.
        :rtype: str
        """
        return self._operate_type

    @operate_type.setter
    def operate_type(self, operate_type):
        """Sets the operate_type of this FirewallRule.

        网络ACL规则操作状态，作为请求时取值为\"add\"/\"modify\"/\"delete\"，作为返回值时为\"normal\"。 当请求更新规则时，本参数值为delete时，除id之外，本请求体其他参数均可为空。

        :param operate_type: The operate_type of this FirewallRule.
        :type: str
        """
        self._operate_type = operate_type

    @property
    def protocol(self):
        """Gets the protocol of this FirewallRule.

        IP协议，为any时代表所有协议  取值范围：icmp，tcp，udp，[icmpv6，](tag:hide)any 

        :return: The protocol of this FirewallRule.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this FirewallRule.

        IP协议，为any时代表所有协议  取值范围：icmp，tcp，udp，[icmpv6，](tag:hide)any 

        :param protocol: The protocol of this FirewallRule.
        :type: str
        """
        self._protocol = protocol

    @property
    def source_ip_address(self):
        """Gets the source_ip_address of this FirewallRule.

        源IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :return: The source_ip_address of this FirewallRule.
        :rtype: str
        """
        return self._source_ip_address

    @source_ip_address.setter
    def source_ip_address(self, source_ip_address):
        """Sets the source_ip_address of this FirewallRule.

        源IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :param source_ip_address: The source_ip_address of this FirewallRule.
        :type: str
        """
        self._source_ip_address = source_ip_address

    @property
    def source_port(self):
        """Gets the source_port of this FirewallRule.

        源地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :return: The source_port of this FirewallRule.
        :rtype: str
        """
        return self._source_port

    @source_port.setter
    def source_port(self, source_port):
        """Sets the source_port of this FirewallRule.

        源地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :param source_port: The source_port of this FirewallRule.
        :type: str
        """
        self._source_port = source_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallRule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiec-3.0.54-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/firewall_rule.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FirewallRule:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'action': 'str',
        'description': 'str',
        'destination_ip_address': 'str',
        'destination_port': 'str',
        'enabled': 'bool',
        'id': 'str',
        'ip_version': 'int',
        'name': 'str',
        'operate_type': 'str',
        'protocol': 'str',
        'source_ip_address': 'str',
        'source_port': 'str'
    }

    attribute_map = {
        'action': 'action',
        'description': 'description',
        'destination_ip_address': 'destination_ip_address',
        'destination_port': 'destination_port',
        'enabled': 'enabled',
        'id': 'id',
        'ip_version': 'ip_version',
        'name': 'name',
        'operate_type': 'operate_type',
        'protocol': 'protocol',
        'source_ip_address': 'source_ip_address',
        'source_port': 'source_port'
    }

    def __init__(self, action=None, description=None, destination_ip_address=None, destination_port=None, enabled=None, id=None, ip_version=None, name=None, operate_type=None, protocol=None, source_ip_address=None, source_port=None):
        """FirewallRule - a model defined in huaweicloud sdk"""
        
        

        self._action = None
        self._description = None
        self._destination_ip_address = None
        self._destination_port = None
        self._enabled = None
        self._id = None
        self._ip_version = None
        self._name = None
        self._operate_type = None
        self._protocol = None
        self._source_ip_address = None
        self._source_port = None
        self.discriminator = None

        self.action = action
        if description is not None:
            self.description = description
        self.destination_ip_address = destination_ip_address
        self.destination_port = destination_port
        self.enabled = enabled
        self.id = id
        self.ip_version = ip_version
        self.name = name
        self.operate_type = operate_type
        self.protocol = protocol
        self.source_ip_address = source_ip_address
        self.source_port = source_port

    @property
    def action(self):
        """Gets the action of this FirewallRule.

        策略是否允许  取值范围：allow，deny，reject

        :return: The action of this FirewallRule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this FirewallRule.

        策略是否允许  取值范围：allow，deny，reject

        :param action: The action of this FirewallRule.
        :type: str
        """
        self._action = action

    @property
    def description(self):
        """Gets the description of this FirewallRule.

        网络ACL规则描述。

        :return: The description of this FirewallRule.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FirewallRule.

        网络ACL规则描述。

        :param description: The description of this FirewallRule.
        :type: str
        """
        self._description = description

    @property
    def destination_ip_address(self):
        """Gets the destination_ip_address of this FirewallRule.

        目的地IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :return: The destination_ip_address of this FirewallRule.
        :rtype: str
        """
        return self._destination_ip_address

    @destination_ip_address.setter
    def destination_ip_address(self, destination_ip_address):
        """Sets the destination_ip_address of this FirewallRule.

        目的地IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :param destination_ip_address: The destination_ip_address of this FirewallRule.
        :type: str
        """
        self._destination_ip_address = destination_ip_address

    @property
    def destination_port(self):
        """Gets the destination_port of this FirewallRule.

        目的地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :return: The destination_port of this FirewallRule.
        :rtype: str
        """
        return self._destination_port

    @destination_port.setter
    def destination_port(self, destination_port):
        """Sets the destination_port of this FirewallRule.

        目的地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :param destination_port: The destination_port of this FirewallRule.
        :type: str
        """
        self._destination_port = destination_port

    @property
    def enabled(self):
        """Gets the enabled of this FirewallRule.

        网络ACL规则使能开关。  取值范围：true，false

        :return: The enabled of this FirewallRule.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this FirewallRule.

        网络ACL规则使能开关。  取值范围：true，false

        :param enabled: The enabled of this FirewallRule.
        :type: bool
        """
        self._enabled = enabled

    @property
    def id(self):
        """Gets the id of this FirewallRule.

        网络ACL规则ID。  进行更新规则时，如果operate_type为add，则该值为空。

        :return: The id of this FirewallRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FirewallRule.

        网络ACL规则ID。  进行更新规则时，如果operate_type为add，则该值为空。

        :param id: The id of this FirewallRule.
        :type: str
        """
        self._id = id

    @property
    def ip_version(self):
        """Gets the ip_version of this FirewallRule.

        IP协议版本  取值范围：4[、6](tag:hide)

        :return: The ip_version of this FirewallRule.
        :rtype: int
        """
        return self._ip_version

    @ip_version.setter
    def ip_version(self, ip_version):
        """Sets the ip_version of this FirewallRule.

        IP协议版本  取值范围：4[、6](tag:hide)

        :param ip_version: The ip_version of this FirewallRule.
        :type: int
        """
        self._ip_version = ip_version

    @property
    def name(self):
        """Gets the name of this FirewallRule.

        网络ACL规则名称。

        :return: The name of this FirewallRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FirewallRule.

        网络ACL规则名称。

        :param name: The name of this FirewallRule.
        :type: str
        """
        self._name = name

    @property
    def operate_type(self):
        """Gets the operate_type of this FirewallRule.

        网络ACL规则操作状态，作为请求时取值为\"add\"/\"modify\"/\"delete\"，作为返回值时为\"normal\"。 当请求更新规则时，本参数值为delete时，除id之外，本请求体其他参数均可为空。

        :return: The operate_type of this FirewallRule.
        :rtype: str
        """
        return self._operate_type

    @operate_type.setter
    def operate_type(self, operate_type):
        """Sets the operate_type of this FirewallRule.

        网络ACL规则操作状态，作为请求时取值为\"add\"/\"modify\"/\"delete\"，作为返回值时为\"normal\"。 当请求更新规则时，本参数值为delete时，除id之外，本请求体其他参数均可为空。

        :param operate_type: The operate_type of this FirewallRule.
        :type: str
        """
        self._operate_type = operate_type

    @property
    def protocol(self):
        """Gets the protocol of this FirewallRule.

        IP协议，为any时代表所有协议  取值范围：icmp，tcp，udp，[icmpv6，](tag:hide)any 

        :return: The protocol of this FirewallRule.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this FirewallRule.

        IP协议，为any时代表所有协议  取值范围：icmp，tcp，udp，[icmpv6，](tag:hide)any 

        :param protocol: The protocol of this FirewallRule.
        :type: str
        """
        self._protocol = protocol

    @property
    def source_ip_address(self):
        """Gets the source_ip_address of this FirewallRule.

        源IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :return: The source_ip_address of this FirewallRule.
        :rtype: str
        """
        return self._source_ip_address

    @source_ip_address.setter
    def source_ip_address(self, source_ip_address):
        """Sets the source_ip_address of this FirewallRule.

        源IP地址，IPv4[或IPv6](tag:hide)的CIDR格式

        :param source_ip_address: The source_ip_address of this FirewallRule.
        :type: str
        """
        self._source_ip_address = source_ip_address

    @property
    def source_port(self):
        """Gets the source_port of this FirewallRule.

        源地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :return: The source_port of this FirewallRule.
        :rtype: str
        """
        return self._source_port

    @source_port.setter
    def source_port(self, source_port):
        """Sets the source_port of this FirewallRule.

        源地端口范围  取值范围：整数，比如80，或者以\"-\"隔开的范围，比如80-90

        :param source_port: The source_port of this FirewallRule.
        :type: str
        """
        self._source_port = source_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallRule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
